@@ -39,10 +39,10 @@
 
 MainWindow::MainWindow(QWidget *parent) :
     KXmlGuiWindow(parent),
-    m_key_pos("window/position"), m_in_progress(false), m_mode(Random)
+    m_key_pos(QStringLiteral("window/position")), m_in_progress(false), m_mode(Random)
 {
-    QCoreApplication::setApplicationName("picmi");
-    QCoreApplication::setOrganizationDomain("kde.org");
+    QCoreApplication::setApplicationName(QStringLiteral("picmi"));
+    QCoreApplication::setOrganizationDomain(QStringLiteral("kde.org"));
 
     m_timer.setInterval(500);
 
@@ -55,30 +55,30 @@ MainWindow::MainWindow(QWidget *parent) :
 }
 
 void MainWindow::setupActions() {
-    KStandardGameAction::gameNew(this, SLOT(startRandomGame()), actionCollection());
-    KStandardGameAction::load(this, SLOT(loadBoard()), actionCollection());
-    KStandardGameAction::restart(this, SLOT(restartGame()), actionCollection());
-    KStandardGameAction::highscores(this, SLOT(highscores()), actionCollection());
-    KStandardGameAction::quit(this, SLOT(close()), actionCollection());
-    KStandardAction::preferences(this, SLOT(settings()), actionCollection());
-    KStandardAction::fullScreen(this, SLOT(toggleFullscreen(bool)), this, actionCollection());
-    m_action_pause = KStandardGameAction::pause(this, SLOT(togglePaused(bool)), actionCollection());
-    m_action_undo = KStandardGameAction::undo(this, SLOT(undo()), actionCollection());
-    m_action_hint = KStandardGameAction::hint(this, SLOT(hint()), actionCollection());
-    m_action_solve = KStandardGameAction::solve(this, SLOT(solve()), actionCollection());
+    KStandardGameAction::gameNew(this, &MainWindow::startRandomGame, actionCollection());
+    KStandardGameAction::load(this, &MainWindow::loadBoard, actionCollection());
+    KStandardGameAction::restart(this, &MainWindow::restartGame, actionCollection());
+    KStandardGameAction::highscores(this, &MainWindow::highscores, actionCollection());
+    KStandardGameAction::quit(this, &MainWindow::close, actionCollection());
+    KStandardAction::preferences(this, &MainWindow::settings, actionCollection());
+    KStandardAction::fullScreen(this, &MainWindow::toggleFullscreen, this, actionCollection());
+    m_action_pause = KStandardGameAction::pause(this, &MainWindow::togglePaused, actionCollection());
+    m_action_undo = KStandardGameAction::undo(this, &MainWindow::undo, actionCollection());
+    m_action_hint = KStandardGameAction::hint(this, &MainWindow::hint, actionCollection());
+    m_action_solve = KStandardGameAction::solve(this, &MainWindow::solve, actionCollection());
 
     /* Prevent the default hint shortcut from overwriting our HJKL vim-like control mapping. */
     actionCollection()->setDefaultShortcut(m_action_hint, QKeySequence(Qt::CTRL | Qt::Key_I));
 
-    m_action_save_state = actionCollection()->addAction("save-position");
+    m_action_save_state = actionCollection()->addAction(QStringLiteral("save-position"));
     m_action_save_state->setText(i18n("Save Position"));
-    m_action_save_state->setIcon(QIcon::fromTheme("list-add"));
+    m_action_save_state->setIcon(QIcon::fromTheme(QStringLiteral("list-add")));
     actionCollection()->setDefaultShortcut(m_action_save_state, QKeySequence(Qt::CTRL | Qt::Key_S));
-    connect(m_action_save_state, SIGNAL(triggered()), this, SLOT(saveState()));
+    connect(m_action_save_state, &QAction::triggered, this, &MainWindow::saveState);
 
-    m_action_load_state = actionCollection()->addAction("load-position");
+    m_action_load_state = actionCollection()->addAction(QStringLiteral("load-position"));
     m_action_load_state->setText(i18n("Load Position"));
-    m_action_load_state->setIcon(QIcon::fromTheme("view-refresh"));
+    m_action_load_state->setIcon(QIcon::fromTheme(QStringLiteral("view-refresh")));
     actionCollection()->setDefaultShortcut(m_action_load_state, QKeySequence(Qt::CTRL | Qt::Key_L));
     connect(m_action_load_state, &QAction::triggered, this, &MainWindow::loadState);
 
@@ -313,6 +313,7 @@ void MainWindow::gameCompleted() {
     m_action_load_state->setEnabled(false);
     Kg::difficulty()->setGameRunning(false);
     m_timer.stop();
+    updatePlayedTime();
     m_in_progress = false;
 }
 
